package LineField;
# ESA (C) 2000-2018 
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
require 5.004;
use Carp;
use strict;
use FileHandle;

sub new {
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my $field = shift;
    my $self = {};
    $self->{TYPE} = undef;
    $self->{ELEMENTS} = undef;
    $self->{CONTENT} = $field;

    if(ref $field) {
	$self->{TYPE} = 'numeric';
	$self->{ELEMENTS} = $#$field;
    } else {
	$self->{TYPE} = 'string';
	$self->{ELEMENTS} = 1;
    }
    
    bless $self, $class;
    return $self;
}

sub isString {
    my $self = shift;
    return ($self->{TYPE} eq 'string');
}

sub elements {
    my $self = shift;
    return length $self->{CONTENT} if $self->isString;
    return scalar @{$self->{CONTENT}};
}

sub getField {
    my $self = shift;
    my $fn = shift;
    return (substr $self->{CONTENT}, $fn, 1) if $self->isString;
    croak "This field does not exist\n" if $self->elements < $fn;
    return $self->{CONTENT}->[$fn];
}

1;
